;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "org-modern" "1.13"
  "Modern looks for Org."
  '((emacs  "29.1")
    (org    "9.6")
    (compat "30"))
  :url "https://github.com/minad/org-modern"
  :commit "f514a2570da0f7a8ff0d72641458dbcf96ccf702"
  :revdesc "1.13-0-gf514a2570da0"
  :keywords '("outlines" "hypermedia" "text")
  :authors '(("Daniel Mendler" . "mail@daniel-mendler.de"))
  :maintainers '(("Daniel Mendler" . "mail@daniel-mendler.de")))
